import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  arc,
  scaleBand,
  scaleLinear,
  max,
  format,
  scaleOrdinal,
} from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import { ColorLegend } from './ColorLegend';
import { PlotMenu } from './PlotMenu';

const width = 960;
const height = 500;
const margin = {
  top: 20,
  right: 170,
  bottom: 105,
  left: 180,
};
const xAxisLabelOffset = 50;

const menuLabels = ['Ukupno', 'COVID-19', 'Ostale svrhe'];

const App = () => {
  const data = useData();

  const initialXAttribute = 'ActionsPTC';
  const [xAttribute, setXAttribute] = useState(
    initialXAttribute
  );
  const xValue = (d) => d[xAttribute];

  const initialX2Attribute = 'AmountPTC';
  const [x2Attribute, setX2Attribute] = useState(
    initialX2Attribute
  );
  const x2Value = (d) => d[x2Attribute];

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const xAxisLabel = '';
  //const xValue = (d) => d.ActionsPTC;

  //const x2Value = (d) => d.AmountPTC;
  const yValue = (d) => d.DonorType;
  const colorValue = ['COVID-19', 'Ostel svrhe'];

  // const xFirstRectValue = (d) => d.ActionsCOVID;
  const xFirstRectValue =
    initialX2Attribute == x2Attribute
      ? (d) => d.ActionsCOVID
      : (d) => d.Zero;
  //const xSecondRectValue = (d) => d.ActionsOTHER;
  const xSecondRectValue =
    initialX2Attribute == x2Attribute
      ? (d) => d.ActionsOTHER
      : (d) => d.Hundred;
  //const x2FirstRectValue = (d) => d.AmountCOVID;
  const x2FirstRectValue =
    initialX2Attribute == x2Attribute
      ? (d) => d.AmountCOVID
      : (d) => d.Zero;
  //const x2SecondRectValue = (d) => d.AmountOTHER;
  const x2SecondRectValue =
    initialX2Attribute == x2Attribute
      ? (d) => d.AmountOTHER
      : (d) => d.Hundred;

  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.65);

  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);

  const x2Scale = scaleLinear()
    .domain([0, max(data, x2Value)])
    .range([0, innerWidth]);

  const colorScale = scaleOrdinal()
    .domain(colorValue)
    .range(['#BD2D28', '#E6842A']);

  const scaleToPass =
    xScale.domain()[1] > x2Scale.domain()[1]
      ? xScale
      : x2Scale;

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        {/*<AxisBottom
          xScale={scaleToPass}
          innerHeight={innerHeight}
        />*/}
        <AxisLeft yScale={yScale} />
        <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor={'middle'}
        >
          {xAxisLabel}
        </text>
        <Marks
          data={data}
          yScale={yScale}
          xScale={scaleToPass}
          xValue={xValue}
          xAttribute={xAttribute}
          x2Value={x2Value}
          x2Attribute={x2Attribute}
          yValue={yValue}
          xFirstRectValue={xFirstRectValue}
          xSecondRectValue={xSecondRectValue}
          x2FirstRectValue={x2FirstRectValue}
          x2SecondRectValue={x2SecondRectValue}
        />
      </g>
      
      <g transform={`translate(${innerHeight + 10}, ${innerHeight})`}>
        <ColorLegend
          xAttribute={xAttribute}
        />
      </g>
      <g
          text-anchor="middle"
          transform={`translate(${innerWidth / 2 + 20} ${
            height - 20
          })`}
        >
        <PlotMenu
          updateXValue={setXAttribute}
          updateX2Value={setX2Attribute}
          menuLabels={menuLabels}
          xAttribute={xAttribute}
        />
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
